@@ -26,34 +26,6 @@ class EbClient(AbstractClient):
     _service = 'eb'
 
 
-    def CheckRule(self, request):
-        """This API is used to check a rule.
-
-        :param request: Request instance for CheckRule.
-        :type request: :class:`tencentcloud.eb.v20210416.models.CheckRuleRequest`
-        :rtype: :class:`tencentcloud.eb.v20210416.models.CheckRuleResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("CheckRule", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CheckRuleResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def CheckTransformation(self, request):
         """This API is used to test rules and data on the ETL configuration page.
 
@@ -64,7 +36,8 @@ class EbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CheckTransformation", params)
+            headers = request.headers
+            body = self.call("CheckTransformation", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CheckTransformationResponse()
@@ -82,62 +55,6 @@ class EbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def CreateConnection(self, request):
-        """This API is used to create an event connector.
-
-        :param request: Request instance for CreateConnection.
-        :type request: :class:`tencentcloud.eb.v20210416.models.CreateConnectionRequest`
-        :rtype: :class:`tencentcloud.eb.v20210416.models.CreateConnectionResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("CreateConnection", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateConnectionResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def CreateEventBus(self, request):
-        """This API is used to create an event bus.
-
-        :param request: Request instance for CreateEventBus.
-        :type request: :class:`tencentcloud.eb.v20210416.models.CreateEventBusRequest`
-        :rtype: :class:`tencentcloud.eb.v20210416.models.CreateEventBusResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("CreateEventBus", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateEventBusResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def CreateRule(self, request):
         """This API is used to create an event rule.
 
@@ -148,7 +65,8 @@ class EbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateRule", params)
+            headers = request.headers
+            body = self.call("CreateRule", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateRuleResponse()
@@ -176,7 +94,8 @@ class EbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateTarget", params)
+            headers = request.headers
+            body = self.call("CreateTarget", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateTargetResponse()
@@ -204,7 +123,8 @@ class EbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateTransformation", params)
+            headers = request.headers
+            body = self.call("CreateTransformation", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateTransformationResponse()
@@ -232,7 +152,8 @@ class EbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteConnection", params)
+            headers = request.headers
+            body = self.call("DeleteConnection", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteConnectionResponse()
@@ -260,7 +181,8 @@ class EbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteEventBus", params)
+            headers = request.headers
+            body = self.call("DeleteEventBus", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteEventBusResponse()
@@ -288,7 +210,8 @@ class EbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteRule", params)
+            headers = request.headers
+            body = self.call("DeleteRule", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteRuleResponse()
@@ -316,7 +239,8 @@ class EbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteTarget", params)
+            headers = request.headers
+            body = self.call("DeleteTarget", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteTargetResponse()
@@ -344,7 +268,8 @@ class EbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteTransformation", params)
+            headers = request.headers
+            body = self.call("DeleteTransformation", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteTransformationResponse()
@@ -362,34 +287,6 @@ class EbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def GetEventBus(self, request):
-        """This API is used to get the details of an event bus.
-
-        :param request: Request instance for GetEventBus.
-        :type request: :class:`tencentcloud.eb.v20210416.models.GetEventBusRequest`
-        :rtype: :class:`tencentcloud.eb.v20210416.models.GetEventBusResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("GetEventBus", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.GetEventBusResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def GetRule(self, request):
         """This API is used to get the details of an event rule.
 
@@ -400,7 +297,8 @@ class EbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetRule", params)
+            headers = request.headers
+            body = self.call("GetRule", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetRuleResponse()
@@ -428,7 +326,8 @@ class EbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetTransformation", params)
+            headers = request.headers
+            body = self.call("GetTransformation", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetTransformationResponse()
@@ -456,7 +355,8 @@ class EbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ListConnections", params)
+            headers = request.headers
+            body = self.call("ListConnections", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ListConnectionsResponse()
@@ -484,7 +384,8 @@ class EbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ListEventBuses", params)
+            headers = request.headers
+            body = self.call("ListEventBuses", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ListEventBusesResponse()
@@ -512,7 +413,8 @@ class EbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ListRules", params)
+            headers = request.headers
+            body = self.call("ListRules", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ListRulesResponse()
@@ -540,7 +442,8 @@ class EbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ListTargets", params)
+            headers = request.headers
+            body = self.call("ListTargets", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ListTargetsResponse()
@@ -568,7 +471,8 @@ class EbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdateConnection", params)
+            headers = request.headers
+            body = self.call("UpdateConnection", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpdateConnectionResponse()
@@ -586,34 +490,6 @@ class EbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def UpdateEventBus(self, request):
-        """This API is used to update an event bus.
-
-        :param request: Request instance for UpdateEventBus.
-        :type request: :class:`tencentcloud.eb.v20210416.models.UpdateEventBusRequest`
-        :rtype: :class:`tencentcloud.eb.v20210416.models.UpdateEventBusResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("UpdateEventBus", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.UpdateEventBusResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def UpdateRule(self, request):
         """This API is used to update an event rule.
 
@@ -624,7 +500,8 @@ class EbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdateRule", params)
+            headers = request.headers
+            body = self.call("UpdateRule", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpdateRuleResponse()
@@ -652,7 +529,8 @@ class EbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdateTarget", params)
+            headers = request.headers
+            body = self.call("UpdateTarget", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpdateTargetResponse()
@@ -680,7 +558,8 @@ class EbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdateTransformation", params)
+            headers = request.headers
+            body = self.call("UpdateTransformation", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpdateTransformationResponse()
