@@ -27,7 +27,8 @@ class EmrClient(AbstractClient):
 
 
     def AddUsersForUserManager(self, request):
-        """This API is used to add user lists (user management).
+        """This API is available for clusters with OpenLDAP components configured.
+        This API is used to add user lists (user management).
 
         :param request: Request instance for AddUsersForUserManager.
         :type request: :class:`tencentcloud.emr.v20190103.models.AddUsersForUserManagerRequest`
@@ -201,7 +202,8 @@ class EmrClient(AbstractClient):
 
 
     def DescribeUsersForUserManager(self, request):
-        """This API is used to export users in batches.
+        """This API is available for clusters with OpenLDAP components configured.
+        This API is used to export users in batches. For a Kerberos cluster, set `NeedKeytabInfo` to `true` to obtain the download link of the Keytab file. If `SupportDownLoadKeyTab` is `true`, but `DownLoadKeyTabUrl` is null, the Keytab file is not ready yet (being generated) in the backend.
 
         :param request: Request instance for DescribeUsersForUserManager.
         :type request: :class:`tencentcloud.emr.v20190103.models.DescribeUsersForUserManagerRequest`
