@@ -23,6 +23,9 @@ INTERNALERROR_BACKENDERROR = 'InternalError.BackendError'
 # Failed to get configuration
 INTERNALERROR_DOMAINCONFIG = 'InternalError.DomainConfig'
 
+# Failed to generate an upload link.
+INTERNALERROR_FAILEDTOGENERATEURL = 'InternalError.FailedToGenerateUrl'
+
 # Server error.
 INTERNALERROR_QUOTASYSTEM = 'InternalError.QuotaSystem'
 
@@ -47,8 +50,17 @@ LIMITEXCEEDED_BATCHQUOTA = 'LimitExceeded.BatchQuota'
 # Reached the daily upper limit of resource number
 LIMITEXCEEDED_DAILYQUOTA = 'LimitExceeded.DailyQuota'
 
+# 
+OPERATIONDENIED = 'OperationDenied'
+
+# 
+RESOURCEUNAVAILABLE = 'ResourceUnavailable'
+
 # CAM is not authorized.
 UNAUTHORIZEDOPERATION_CAMUNAUTHORIZED = 'UnauthorizedOperation.CamUnauthorized'
 
+# 
+UNAUTHORIZEDOPERATION_DOMAINEMPTY = 'UnauthorizedOperation.DomainEmpty'
+
 # The sub-account is not authorized for the operation. Please add permissions first.
 UNAUTHORIZEDOPERATION_NOPERMISSION = 'UnauthorizedOperation.NoPermission'
